Printing for Geometric Algebra
==============================

.. module:: sympy.galgebra.printing

Class Reference
---------------

.. autoclass:: enhance_print
   :members:

.. autoclass:: GA_Printer
   :members:

.. autoclass:: GA_LatexPrinter
   :members:

Function Reference
------------------

.. autofunction:: find_executable

.. autofunction:: Get_Program

.. autofunction:: latex

.. autofunction:: Print_Function

.. autofunction:: print_latex

.. autofunction:: xdvi
